@@ -1,9 +1,17 @@
 #====================================================================
 # All GillespieSSA demos 
 #====================================================================
+
+# Chemical kinetics models
 demo(decayingDimer)
 demo(linearChain)
+
+# Ecological models
 demo(logisticGrowth)
 demo(lotka)
-demo(rma)
 demo(sir)
+
+# Models from Pineda-Krch, [submitted JSS manuscript] 
+demo(rma)
+demo(lgr)
+demo(epiChain)
