@@ -25,7 +25,7 @@ diag(nu[2:M,]) <- +1
 nu[M+1,M] <- +1
 
 # Propensity vector
-a <- as.vector(paste("c*{x",seq(M),"}",sep=""))
+a <- as.vector(paste("c*x",seq(M),"",sep=""))
 
 tf <- 10 # Final time
 simName <- "Linear Chain System"
@@ -33,17 +33,21 @@ simName <- "Linear Chain System"
 # Run the simulations
 
 # Direct method
+set.seed(1)
 out <- ssa(x0,a,nu,parms,tf,method="D",simName,maxWallTime=5)
 ssa.plot(out)
 
 # Explict tau-leap method
+set.seed(1)
 out <- ssa(x0,a,nu,parms,tf,method="ETL",simName,tau=0.1,maxWallTime=5)
 ssa.plot(out)
 
 # Binomial tau-leap method
+set.seed(1)
 out <- ssa(x0,a,nu,parms,tf,method="BTL",simName,f=50,maxWallTime=5)
 ssa.plot(out)
 
 # Optimal tau-leap method
+set.seed(1)
 out <- ssa(x0,a,nu,parms,tf,method="OTL",simName,maxWallTime=5)
 ssa.plot(out)
