@@ -7,9 +7,9 @@
 # dI/dt = beta*N*S - gamma*I
 # dR/dt = gamma*I
 #
-# This model has two reaction channels,
-#  S + I --beta--> I
-#      I --gamma-> R
+# This model consists of two reactions with the following per capita rates,
+# transmission: beta
+# recovery:     gamma
 
 library(GillespieSSA)
 
@@ -17,26 +17,30 @@ library(GillespieSSA)
 parms <- c(beta=.001, gamma=.100)
 
 # Define system
-x0  <- c(S=500, I=1, R=0)                      # Initial state vector
-nu  <- matrix(c(-1,0,1,-1,0,1),nrow=3,byrow=T) # State-change matrix
-a   <- c("beta*{S}*{I}", "gamma*{I}")          # Propensity vector
-tf <- 100                                      # Final time
+x0 <- c(S=500, I=1, R=0)                      # Initial state vector
+nu <- matrix(c(-1,0,1,-1,0,1),nrow=3,byrow=T) # State-change matrix
+a  <- c("beta*S*I", "gamma*I")                # Propensity vector
+tf <- 100                                     # Final time
 simName <- "Kermack-McKendrick SIR"
 
 # Run the simulations
 
 # Direct method
+set.seed(2)
 out <- ssa(x0,a,nu,parms,tf,method="D",simName)
 ssa.plot(out) 
 
 # Explicit tau-leap method
+set.seed(2)
 out <- ssa(x0,a,nu,parms,tf,method="ETL",simName)
 ssa.plot(out) 
 
 # Binomial tau-leap method
+set.seed(2)
 out <- ssa(x0,a,nu,parms,tf,method="BTL",simName)
 ssa.plot(out) 
 
 # Optimized tau-leap method
+set.seed(2)
 out <- ssa(x0,a,nu,parms,tf,method="OTL",simName)
 ssa.plot(out) 
